@@ -95,7 +95,7 @@ class TSPipeline(object):
                 path = file.filename
                 if hasattr(file.fetcher, "pathondisk"):
                     path = file.fetcher.pathondisk
-                print(f"\n{exc.__class__.__name__}: {str(exc)} while processing '{path}'\n", file=stderr)
+                print(f"\n{exc.__class__.__name__}: {str(exc)} in {step.__class__.__name__} while processing '{path}'\n", file=stderr)
                 if stderr.isatty():
                     traceback.print_exc(file=stderr)
                 file.report["Errors"] = f"{exc.__class__.__name__}: {str(exc)}"
