@@ -8,8 +8,9 @@ from .base import *
 from .imageio import *
 
 import numpy as np
-import cv2
+
 from skimage.transform import rescale
+import skimage as ski
 import re
 
 
@@ -42,7 +43,7 @@ def ceil2(x):
     :returns: Rounded number
     :rtype: int
     """
-    return int(np.ceil(x/2)*2)
+    return int(np.ceil(x / 2) * 2)
 
 
 class GenericDownsizerStep(PipelineStep):
@@ -56,7 +57,8 @@ class GenericDownsizerStep(PipelineStep):
       * a scale factor, or
       * a dimension string.
     """
-    def __init__(self, rows=None, cols=None, scale=None, geom=None):
+
+    def __init__(self, rows=None, cols=None, scale=None, geom=None, interpolation="lanczos"):
         """
         :param rows: Image height. Has to be an even number.
         :type rows: int
@@ -67,6 +69,8 @@ class GenericDownsizerStep(PipelineStep):
         :param geom: Dimension string of "<height>x<width>"
         :type geom: str
         """
+
+        self.interpolation = interpolation
         if geom is not None:
             rows, cols = geom2rowcol(geom)
         if rows is None and cols is None and scale is None:
@@ -107,6 +111,17 @@ class ResizeImageStep(GenericDownsizerStep):
     """Pipeline step which resizes an entire image to rows * cols"""
 
     def process_file(self, file):
+        import cv2
+        interp_values = {
+            "nearest": cv2.INTER_NEAREST,
+            "nearest_exact": cv2.INTER_NEAREST_EXACT,
+            "area": cv2.INTER_AREA,
+            "linear": cv2.INTER_LINEAR,
+            "linear_exact": cv2.INTER_LINEAR_EXACT,
+            "cubic": cv2.INTER_CUBIC,
+            "lanczos": cv2.INTER_LANCZOS4,
+        }
+
         assert hasattr(file, "pixels")  # TODO proper check
 
         if self.scale is not None:
@@ -120,7 +135,7 @@ class ResizeImageStep(GenericDownsizerStep):
             rows, cols = self._new_imagesize(file.pixels.shape)
             if len(file.pixels.shape) == 3:
                 newpixels = cv2.resize(file.bgr_8, dsize=(cols, rows),
-                                       interpolation=cv2.INTER_LANCZOS4)[:, :, ::-1]  # back to rgb
+                                       interpolation=interp_values.get(self.interpolation, cv2.INTER_LANCZOS4))[:, :, ::-1]  # back to rgb
             elif len(file.pixels.shape) == 2:
                 # handle greyscale images better
                 newpixels = ski.transform.resize(file.pixels, np.round((rows, cols)),
@@ -129,6 +144,24 @@ class ResizeImageStep(GenericDownsizerStep):
         return TimestreamImage.from_timestreamfile(file, pixels=newpixels)
 
 
+class ResizeImageStepSKI(GenericDownsizerStep):
+    """Pipeline step which resizes an entire image to rows * cols
+    uses skimage instead of opencv
+    """
+
+    def process_file(self, file):
+        assert hasattr(file, "pixels")  # TODO proper check
+
+        if self.scale is not None:
+            newpixels = rescale(file.pixels, self.scale, order=3, anti_aliasing=True)
+        else:
+            newpixels = ski.transform.resize(file.pixels,
+                                             np.round(self._new_imagesize(file.pixels.shape)),
+                                             order=3, anti_aliasing=True)
+
+        return TimestreamImage.from_timestreamfile(file, pixels=newpixels)
+
+
 class CropCentreStep(GenericDownsizerStep):
     """Pipeline step which resizes an image to rows * cols"""
 
@@ -140,6 +173,6 @@ class CropCentreStep(GenericDownsizerStep):
         left = int((orow - rows) / 2)
         top = int((ocol - cols) / 2)
 
-        newpixels = file.pixels[left:left+rows, top:top+cols, :]
+        newpixels = file.pixels[left:left + rows, top:top + cols, :]
 
         return TimestreamImage.from_timestreamfile(file, pixels=newpixels)
