@@ -27,7 +27,7 @@ def parse_date(datestr):
     :return: Datetime object representing the given string
     :rtype: :class:`datetime.datetime` object
     """
-    if isinstance(datestr, datetime.datetime):
+    if isinstance(datestr, datetime.date):
         return datestr
 
     valid_formats = [
@@ -95,6 +95,9 @@ class TSInstant(object):
         :type index: int or string containing a usable int, optional
         """
         self.datetime = parse_date(datetime)
+
+        if self.datetime.tzinfo is None:
+            self.datetime = tz.localize(self.datetime)
         self.index = index
 
     @property
